@@ -886,162 +886,6 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
           memcpy(keyword, cur_token_ptr, str_len);
           keyword[str_len] = '\0';
           
-          switch (keyword[0]) {
-            // Keyword
-            case 'c' :
-              if (strcmp(keyword, "case") == 0) {
-                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_CASE);
-                return CASE;
-              }
-              else if (strcmp(keyword, "const") == 0) {
-                SPVM_OP* op = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_DESCRIPTOR);
-                op->code = SPVM_DESCRIPTOR_C_CODE_CONST;
-                yylvalp->opval = op;
-                
-                return DESCRIPTOR;
-              }
-              break;
-            case 'd' :
-              if (strcmp(keyword, "default") == 0) {
-                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_DEFAULT);
-                return DEFAULT;
-              }
-              else if (strcmp(keyword, "die") == 0) {
-                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_DIE);
-                return DIE;
-              }
-              break;
-            case 'e' :
-              if (strcmp(keyword, "elsif") == 0) {
-                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_ELSIF);
-                return ELSIF;
-              }
-              else if (strcmp(keyword, "else") == 0) {
-                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_ELSE);
-                return ELSE;
-              }
-              else if (strcmp(keyword, "enum") == 0) {
-                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_ENUM);
-                return ENUM;
-              }
-              else if (strcmp(keyword, "eval") == 0) {
-                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_EVAL);
-                return EVAL;
-              }
-              break;
-            case 'f' :
-              if (strcmp(keyword, "for") == 0) {
-                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_FOR);
-                return FOR;
-              }
-              break;
-            case 'h' :
-              if (strcmp(keyword, "has") == 0) {
-                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_FIELD);
-                return HAS;
-              }
-              break;
-            case 'i' :
-              if (strcmp(keyword, "if") == 0) {
-                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_IF);
-                return IF;
-              }
-              break;
-            case 'l' :
-              if (strcmp(keyword, "last") == 0) {
-                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_LAST);
-                return LAST;
-              }
-              else if (strcmp(keyword, "len") == 0) {
-                compiler->bufptr++;
-                SPVM_OP* op = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_ARRAY_LENGTH);
-                yylvalp->opval = op;
-                
-                return ARRAY_LENGTH;
-              }
-              break;
-            case 'm' :
-              if (strcmp(keyword, "my") == 0) {
-                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_MY);
-                return MY;
-              }
-              break;
-            case 'n' :
-              if (strcmp(keyword, "native") == 0) {
-                SPVM_OP* op = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_DESCRIPTOR);
-                op->code = SPVM_DESCRIPTOR_C_CODE_NATIVE;
-                yylvalp->opval = op;
-                
-                return DESCRIPTOR;
-              }
-              else if (strcmp(keyword, "next") == 0) {
-                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_NEXT);
-                return NEXT;
-              }
-              else if (strcmp(keyword, "new") == 0) {
-                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_NEW);
-                return NEW;
-              }
-              break;
-            case 'p' :
-              if (strcmp(keyword, "package") == 0) {
-                // File can contains only one package
-                if (compiler->current_package_count) {
-                  fprintf(stderr, "Can't write second package declaration in file at %s line %" PRId32 "\n", compiler->cur_file, compiler->cur_line);
-                  exit(EXIT_FAILURE);
-                }
-                compiler->current_package_count++;
-                
-                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_PACKAGE);
-                return PACKAGE;
-              }
-              break;
-            case 'r' :
-              if (strcmp(keyword, "return") == 0) {
-                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_RETURN);
-                return RETURN;
-              }
-              break;
-            case 's' :
-              if (strcmp(keyword, "switch") == 0) {
-                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_SWITCH);
-                return SWITCH;
-              }
-              else if (strcmp(keyword, "sub") == 0) {
-                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_SUB);
-                return SUB;
-              }
-              break;
-            case 'u' :
-              if (strcmp(keyword, "undef") == 0) {
-                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_UNDEF);
-                return UNDEF;
-              }
-              else if (strcmp(keyword, "use") == 0) {
-                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_USE);
-                return USE;
-              }
-              break;
-            case 'v' :
-              if (strcmp(keyword, "void") == 0) {
-                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_VOID);
-                return VOID;
-              }
-              break;
-            case 'w' :
-              if (strcmp(keyword, "while") == 0) {
-                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_WHILE);
-                return WHILE;
-              }
-              break;
-            case '_':
-              if (strcmp(keyword, "__END__") == 0) {
-                *compiler->bufptr = '\0';
-                continue;
-              }
-              break;
-          }
-          
           // Replace template variable
           const char* found_template_var = strstr(keyword, "type");
           if (found_template_var) {
@@ -1068,7 +912,7 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
                   cur_ptr++;
                 }
               }
-
+              
               SPVM_DYNAMIC_ARRAY* replaced_part_names = SPVM_COMPILER_ALLOCATOR_alloc_array(compiler, compiler->allocator, 0);
               int32_t replaced_part_names_length = 0;
               {
@@ -1122,6 +966,193 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
             }
           }
           
+          switch (keyword[0]) {
+            // Keyword
+            case 'b' :
+              if (strcmp(keyword, "byte") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_BYTE);
+                return BYTE;
+              }
+              break;
+            case 'c' :
+              if (strcmp(keyword, "case") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_CASE);
+                return CASE;
+              }
+              else if (strcmp(keyword, "const") == 0) {
+                SPVM_OP* op = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_DESCRIPTOR);
+                op->code = SPVM_DESCRIPTOR_C_CODE_CONST;
+                yylvalp->opval = op;
+                
+                return DESCRIPTOR;
+              }
+              break;
+            case 'd' :
+              if (strcmp(keyword, "default") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_DEFAULT);
+                return DEFAULT;
+              }
+              else if (strcmp(keyword, "die") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_DIE);
+                return DIE;
+              }
+              else if (strcmp(keyword, "double") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_DOUBLE);
+                return DOUBLE;
+              }
+              break;
+            case 'e' :
+              if (strcmp(keyword, "elsif") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_ELSIF);
+                return ELSIF;
+              }
+              else if (strcmp(keyword, "else") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_ELSE);
+                return ELSE;
+              }
+              else if (strcmp(keyword, "enum") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_ENUM);
+                return ENUM;
+              }
+              else if (strcmp(keyword, "eval") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_EVAL);
+                return EVAL;
+              }
+              break;
+            case 'f' :
+              if (strcmp(keyword, "for") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_FOR);
+                return FOR;
+              }
+              else if (strcmp(keyword, "float") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_FLOAT);
+                return FLOAT;
+              }
+              break;
+            case 'h' :
+              if (strcmp(keyword, "has") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_FIELD);
+                return HAS;
+              }
+              break;
+            case 'i' :
+              if (strcmp(keyword, "if") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_IF);
+                return IF;
+              }
+              else if (strcmp(keyword, "int") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_INT);
+                return INT;
+              }
+              break;
+            case 'l' :
+              if (strcmp(keyword, "last") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_LAST);
+                return LAST;
+              }
+              else if (strcmp(keyword, "len") == 0) {
+                compiler->bufptr++;
+                SPVM_OP* op = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_ARRAY_LENGTH);
+                yylvalp->opval = op;
+                
+                return ARRAY_LENGTH;
+              }
+              else if (strcmp(keyword, "long") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_LONG);
+                return LONG;
+              }
+              break;
+              break;
+            case 'm' :
+              if (strcmp(keyword, "my") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_MY);
+                return MY;
+              }
+              break;
+            case 'n' :
+              if (strcmp(keyword, "native") == 0) {
+                SPVM_OP* op = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_DESCRIPTOR);
+                op->code = SPVM_DESCRIPTOR_C_CODE_NATIVE;
+                yylvalp->opval = op;
+                
+                return DESCRIPTOR;
+              }
+              else if (strcmp(keyword, "next") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_NEXT);
+                return NEXT;
+              }
+              else if (strcmp(keyword, "new") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_NEW);
+                return NEW;
+              }
+              break;
+            case 'p' :
+              if (strcmp(keyword, "package") == 0) {
+                // File can contains only one package
+                if (compiler->current_package_count) {
+                  fprintf(stderr, "Can't write second package declaration in file at %s line %" PRId32 "\n", compiler->cur_file, compiler->cur_line);
+                  exit(EXIT_FAILURE);
+                }
+                compiler->current_package_count++;
+                
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_PACKAGE);
+                return PACKAGE;
+              }
+              break;
+            case 'r' :
+              if (strcmp(keyword, "return") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_RETURN);
+                return RETURN;
+              }
+              break;
+            case 's' :
+              if (strcmp(keyword, "switch") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_SWITCH);
+                return SWITCH;
+              }
+              else if (strcmp(keyword, "sub") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_SUB);
+                return SUB;
+              }
+              else if (strcmp(keyword, "short") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_SHORT);
+                return SHORT;
+              }
+              else if (strcmp(keyword, "string") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_STRING);
+                return STRING;
+              }
+              break;
+            case 'u' :
+              if (strcmp(keyword, "undef") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_UNDEF);
+                return UNDEF;
+              }
+              else if (strcmp(keyword, "use") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_USE);
+                return USE;
+              }
+              break;
+            case 'v' :
+              if (strcmp(keyword, "void") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_VOID);
+                return VOID;
+              }
+              break;
+            case 'w' :
+              if (strcmp(keyword, "while") == 0) {
+                yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_WHILE);
+                return WHILE;
+              }
+              break;
+            case '_':
+              if (strcmp(keyword, "__END__") == 0) {
+                *compiler->bufptr = '\0';
+                continue;
+              }
+              break;
+          }
+          
           SPVM_OP* op = SPVM_TOKE_newOP(compiler, SPVM_OP_C_CODE_NAME);
           op->uv.name = keyword;
           yylvalp->opval = op;
